@@ -258,7 +258,8 @@ sub load {
     }
     local($") = ", ";
     $CPAN::Frontend->myprint(<<END) if $redo && ! $theycalled;
-We have to reconfigure CPAN.pm due to following uninitialized parameters:
+Sorry, we have to rerun the configuration dialog for CPAN.pm due to
+the following indispensable but missing parameters:
 
 @miss
 END
@@ -273,13 +274,31 @@ $configpm initialized.
 sub missing_config_data {
     my(@miss);
     for (
-         "cpan_home", "keep_source_where", "build_dir", "build_cache",
-         "scan_cache", "index_expire", "gzip", "tar", "unzip", "make",
-         "pager",
-         "makepl_arg", "make_arg", "make_install_arg", "urllist",
-         "inhibit_startup_message", "ftp_proxy", "http_proxy", "no_proxy",
-         "prerequisites_policy",
+         "build_cache",
+         "build_dir",
          "cache_metadata",
+         "cpan_home",
+         "ftp_proxy",
+         "gzip",
+         "http_proxy",
+         "index_expire",
+         "inhibit_startup_message",
+         "keep_source_where",
+         "make",
+         "make_arg",
+         "make_install_arg",
+         "makepl_arg",
+         "mbuild_arg",
+         "mbuild_install_arg",
+         "mbuild_install_build_command",
+         "mbuildpl_arg",
+         "no_proxy",
+         "pager",
+         "prerequisites_policy",
+         "scan_cache",
+         "tar",
+         "unzip",
+         "urllist",
         ) {
 	push @miss, $_ unless defined $CPAN::Config->{$_};
     }
@@ -340,3 +359,9 @@ sub cpl {
 }
 
 1;
+
+__END__
+# Local Variables:
+# mode: cperl
+# cperl-indent-level: 2
+# End:
